==> gpac-0.4.0.tar.gz: gpac/applications/osmo4_w32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Osmo4.rc
//
#define IDD_ABOUTBOX                    100
#define IDR_MAINFRAME                   128
#define IDR_GPACTYPE                    129
#define IDD_CONTROL                     132
#define IDI_PLAY                        141
#define IDI_STOP                        142
#define IDD_OPENFILE                    142
#define IDI_PAUSE                       143
#define IDI_MESSAGE                     144
#define IDI_ERR                         145
#define IDD_OPTIONS                     152
#define IDD_OPT_GEN                     154
#define IDD_OPT_RENDER                  155
#define IDD_OPT_AUDIO                   157
#define IDD_OPT_VIDEO                   158
#define IDD_OPT_HTTP                    159
#define IDD_OPT_FONT                    161
#define IDD_OPT_SYSTEMS                 162
#define IDD_OPT_STREAM                  164
#define IDD_PROPERTIES                  166
#define IDD_OPT_DECODER                 167
#define IDD_OPT_RENDER2D                168
#define IDD_OPT_RENDER3D                169
#define IDR_MAINTOOLS                   170
#define ID_MAINSLIDER                   171
#define IDD_SLIDERS                     173
#define IDD_NAVBAR                      176
#define IDD_PLAYLIST                    177
#define IDR_PLAYLIST                    178
#define IDD_OPT_MCACHE                  178
#define IDD_OPT_FILETYPES               179
#define IDR_MENUPL                      182
#define IDD_PASSWD                      188
#define IDC_PLAY                        1006
#define IDC_STOP                        1007
#define IDC_COMBOURL                    1008
#define IDC_BROWSE                      1009
#define IDC_BUTGO                       1010
#define IDC_SPIN_OPT                    1011
#define IDC_OPT_SET_NAME                1012
#define IDC_LANG                        1013
#define IDC_LOOP                        1014
#define IDC_AUTOSTART                   1015
#define IDC_STOPATEND                   1015
#define IDC_LOOKFORSUB                  1015
#define IDC_FILEASSOC                   1016
#define IDC_SINGLE_INSTANCE             1016
#define IDC_NO_CONSOLE                  1017
#define IDC_BIFS_RATE                   1018
#define IDC_DEC_THREAD                  1019
#define IDC_DIRECTRENDER                1020
#define IDC_BIFSDROP                    1023
#define IDC_SPIN_AUDIO                  1024
#define IDC_EDIT_AUDIO                  1025
#define IDC_FORCE_AUDIO                 1026
#define IDC_SPIN_FPS                    1027
#define IDC_AUDIO_FPS                   1028
#define IDC_AUDIO_MULTICH               1029
#define IDC_GD_LIST                     1031
#define IDC_FAST_RENDER                 1032
#define IDC_FORCE_DURATION              1033
#define IDC_VIDEO_LIST                  1033
#define IDC_FORCE_SIZE                  1033
#define IDC_YUV                         1034
#define IDC_USE_RENDER3D                1034
#define IDC_AUDIO_RESYNC                1035
#define IDC_DRAW_BOUNDS                 1035
#define IDC_AUDIO_NOTIFS                1036
#define IDC_CLEAN_CACHE                 1038
#define IDC_RESTART_CACHE               1039
#define IDC_NOTIFY_PROG                 1040
#define IDC_REORDER                     1040
#define IDC_BROWSE_CACHE                1041
#define IDC_DRIVER_LIST                 1044
#define IDC_AA_LIST                     1045
#define IDC_ZOOM_SCALABLE               1046
#define IDC_FONT_LIST                   1050
#define IDC_BROWSE_FONT                 1051
#define IDC_USE_FONT                    1052
#define IDC_TEXTURE_MODE                1052
#define IDC_SAVEOPT                     1053
#define IDC_PORT                        1054
#define IDC_RTSP                        1055
#define IDC_TIMEOUT                     1056
#define IDC_BUFFER                      1057
#define IDC_REBUFFER_LEN                1058
#define IDC_REBUFFER                    1059
#define IDC_ODTREE                      1060
#define IDC_ODINFO                      1064
#define IDC_WORLD                       1065
#define IDC_GOGPAC                      1066
#define IDC_VIEWSG                      1066
#define IDC_GOOSMO4                     1067
#define IDC_DUMP_XMT                    1068
#define IDC_OBJECT_TIME                 1069
#define IDC_FORMAT_YUV                  1070
#define IDC_SWITCH_RES                  1074
#define IDC_AUDEC_LIST                  1075
#define IDC_VIDEC_LIST                  1076
#define IDC_RASTER_OUTLINE              1078
#define IDC_EMUL_POW2                   1079
#define IDC_DISABLE_POLY_AA             1080
#define IDC_WIRE_NONE                   1081
#define IDC_WIRE_ONLY                   1082
#define IDC_WIRE_BOTH                   1083
#define IDC_DISABLE_TX_RECT             1084
#define IDC_BITMAP_USE_PIXEL            1085
#define IDC_SELECT                      1085
#define IDC_TEXTURE_TEXT                1086
#define IDC_NO_BACKCULL                 1086
#define IDC_SLIDER                      1088
#define ID_SLIDER                       1088
#define IDC_VIEWSEL                     1094
#define IDC_ADDRESS                     1096
#define IDC_DUMTXT                      1097
#define IDC_FILELIST                    1109
#define IDC_BROWSE_MCACHE               1110
#define IDC_MCACHE_OVERWRITE            1111
#define IDC_MCACHE_USENAME              1112
#define IDC_BASEPRES                    1113
#define ID_FILE_EXIT                    1114
#define ID_H_ABOUT                      1115
#define ID_PLAYLIST_LOOP                1116
#define ID_FILEOPEN                     1117
#define ID_VIEW_CONTROL                 1118
#define IDC_ASSOCIATE                   1118
#define ID_VIEW_ORIGINAL                1119
#define IDC_FILES_EXT                   1119
#define ID_VIEW_FULLSCREEN              1120
#define IDC_FILES_MIMES                 1120
#define ID_AR_KEEP                      1121
#define IDC_FILES_PLUG                  1121
#define ID_AR_FILL                      1122
#define ID_AR_43                        1123
#define ID_AR_169                       1124
#define ID_AUDIO_VOL                    1124
#define ID_SHORTCUTS                    1125
#define IDC_TXT_SITE                    1125
#define ID_FILE_RESTART                 1126
#define IDC_EDIT_USER                   1126
#define ID_OPT_QUALITY                  1127
#define IDC_EDIT_PASSWORD               1127
#define IDC_DRAW_NORMALS                1127
#define ID_FILE_PROP                    1128
#define ID_FILE_STEP                    1129
#define IDD_CONFIGURE                   1130
#define ID_VIEW_SCALABLE                1131
#define ID_OPEN_URL                     1132
#define ID_FILE_RELOAD                  1133
#define ID_FILE_PLAY                    1134
#define ID_NAVIGATE_NONE                1135
#define ID_NAVIGATE_WALK                1136
#define ID_NAVIGATE_FLY                 1137
#define ID_NAVIGATE_EXAM                1138
#define ID_NAVIGATE_PAN                 1139
#define ID_NAVIGATE_SLIDE               1140
#define ID_NAVIGATE_GAME                1150
#define ID_NAV_RESET                    1151
#define ID_FILE_STOP                    1152
#define ID_BUTTON32806                  1153
#define ID_BUTTON32807                  1154
#define ID_FILE_PREV                    1155
#define ID_FILE_NEXT                    1156
#define ID_FILE_PROPS                   1157
#define ID_SWITCH_RENDER                1158
#define ID_RELOAD_TERMINAL              1159
#define ID_VIEW_PLAYLIST                1160
#define ID_NAVIGATE_ORBIT               1161
#define ID_COLLIDE_NONE                 1162
#define ID_COLLIDE_REG                  1163
#define ID_COLLIDE_DISP                 1164
#define ID_GRAVITY                      1165
#define ID_HEADLIGHT                    1166
#define ID_NAV_INFO                     1167
#define ID_NAV_PREV                     1168
#define ID_NAV_NEXT                     1169
#define ID_CLEAR_NAV                    1170
#define ID_TIMER                        1171
#define ID_FPS                          1172
#define ID_VIEWPORT_EMPTY               1173
#define ID_PL_REM_ALL                   1174
#define ID_PL_REM_DEAD                  1175
#define ID_PL_ADD_DIR_REC               1176
#define ID_PL_ADD_FILE                  1177
#define ID_PL_REM_FILE                  1178
#define ID_PL_OPEN                      1179
#define ID_PL_SAVE                      1180
#define ID_PL_UP                        1181
#define ID_PL_DOWN                      1182
#define ID_VIEW_PL                      1183
#define ID_PL_ADD_DIR                   1184
#define ID_PL_ADD_URL                   1185
#define ID_PL_PLAY                      1186
#define ID_PL_SEL_REV                   1187
#define ID_PL_SORT_TITLE                1188
#define ID_PL_SORT_FILE                 1189
#define ID_PL_SORT_DUR                  1190
#define ID_PL_SORT_REV                  1191
#define ID_PL_RANDOM                    1192
#define ID_ADD_SUBTITLE                 1193
#define ID_NAVIGATE_VR                  1194
#define ID_REC_ENABLE                   1195
#define ID_REC_STOP                     1196
#define ID_REC_ABORT                    1197
#define ID_AUDIO_EMPTY                  1198
#define ID_VIDEO_EMPTY                  1199
#define ID_SUBS_EMPTY                   1200
#define ID_VP_0                         1300
#define ID_VP_1                         1301
#define ID_VP_2                         1302
#define ID_VP_3                         1303
#define ID_VP_4                         1304
#define ID_VP_5                         1305
#define ID_VP_6                         1306
#define ID_VP_7                         1307
#define ID_VP_8                         1308
#define ID_VP_9                         1309
#define ID_VP_10                        1310
#define ID_VP_11                        1311
#define ID_VP_12                        1312
#define ID_VP_13                        1313
#define ID_VP_14                        1314
#define ID_VP_15                        1315
#define ID_VP_16                        1316
#define ID_VP_17                        1317
#define ID_VP_18                        1318
#define ID_VP_19                        1319
#define ID_NAV_PREV_0                   1320
#define ID_NAV_PREV_1                   1321
#define ID_NAV_PREV_2                   1322
#define ID_NAV_PREV_3                   1323
#define ID_NAV_PREV_4                   1324
#define ID_NAV_PREV_5                   1325
#define ID_NAV_PREV_6                   1326
#define ID_NAV_PREV_7                   1327
#define ID_NAV_PREV_8                   1328
#define ID_NAV_PREV_9                   1329
#define ID_NAV_NEXT_0                   1330
#define ID_NAV_NEXT_1                   1331
#define ID_NAV_NEXT_2                   1332
#define ID_NAV_NEXT_3                   1333
#define ID_NAV_NEXT_4                   1334
#define ID_NAV_NEXT_5                   1335
#define ID_NAV_NEXT_6                   1336
#define ID_NAV_NEXT_7                   1337
#define ID_NAV_NEXT_8                   1338
#define ID_NAV_NEXT_9                   1339
#define ID_SELOBJ_0                     1340
#define ID_SELOBJ_1                     1341
#define ID_SELOBJ_2                     1342
#define ID_SELOBJ_3                     1343
#define ID_SELOBJ_4                     1344
#define ID_SELOBJ_5                     1345
#define ID_SELOBJ_6                     1346
#define ID_SELOBJ_7                     1347
#define ID_SELOBJ_8                     1348
#define ID_SELOBJ_9                     1349
#define ID_SETCHAP_FIRST                2000
#define ID_SETCHAP_LAST                 2200

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        189
#define _APS_NEXT_COMMAND_VALUE         32960
#define _APS_NEXT_CONTROL_VALUE         1128
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> gpac-0.4.2.tar.gz: gpac/applications/osmo4_w32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Osmo4.rc
//
#define IDD_ABOUTBOX                    100
#define IDR_MAINFRAME                   128
#define IDR_GPACTYPE                    129
#define IDD_CONTROL                     132
#define IDI_PLAY                        141
#define IDI_STOP                        142
#define IDI_PAUSE                       143
#define IDI_MESSAGE                     144
#define IDI_ERR                         145
#define IDD_OPTIONS                     152
#define IDD_OPT_GEN                     154
#define IDD_OPT_RENDER                  155
#define IDD_OPT_AUDIO                   157
#define IDD_OPT_VIDEO                   158
#define IDD_OPT_HTTP                    159
#define IDD_OPT_FONT                    161
#define IDD_OPT_SYSTEMS                 162
#define IDD_OPT_STREAM                  164
#define IDD_PROPERTIES                  166
#define IDD_OPT_DECODER                 167
#define IDD_OPT_RENDER2D                168
#define IDD_OPT_RENDER3D                169
#define IDR_MAINTOOLS                   170
#define ID_MAINSLIDER                   171
#define IDD_SLIDERS                     173
#define IDD_NAVBAR                      176
#define IDD_PLAYLIST                    177
#define IDR_PLAYLIST                    178
#define IDD_OPT_FILETYPES               179
#define IDR_MENUPL                      182
#define IDD_PASSWD                      188
#define IDC_FILES_MIMES                 1000
#define IDC_FILES_PLUG                  1001
#define ID_AUDIO_VOL                    1002
#define IDC_TXT_SITE                    1003
#define IDC_EDIT_USER                   1004
#define IDC_EDIT_PASSWORD               1005
#define IDC_PLAY                        1006
#define IDC_STOP                        1007
#define IDC_COMBOURL                    1008
#define IDC_BROWSE                      1009
#define IDC_BUTGO                       1010
#define IDC_SPIN_OPT                    1011
#define IDC_OPT_SET_NAME                1012
#define IDC_LANG                        1013
#define IDC_LOOP                        1014
#define IDC_AUTOSTART                   1015
#define IDC_FILEASSOC                   1016
#define IDC_NO_CONSOLE                  1017
#define IDC_BIFS_RATE                   1018
#define IDC_DEC_THREAD                  1019
#define IDC_DIRECTRENDER                1020
#define IDC_HWMEMORY                    1021
#define IDC_BIFSDROP                    1023
#define IDC_SPIN_AUDIO                  1024
#define IDC_EDIT_AUDIO                  1025
#define IDC_FORCE_AUDIO                 1026
#define IDC_SPIN_FPS                    1027
#define IDC_AUDIO_FPS                   1028
#define IDC_AUDIO_MULTICH               1029
#define IDC_GD_LIST                     1031
#define IDC_FAST_RENDER                 1032
#define IDC_FORCE_DURATION              1033
#define IDC_YUV                         1034
#define IDC_AUDIO_RESYNC                1035
#define IDC_AUDIO_NOTIFS                1036
#define IDC_STOPATEND                   1037
#define IDC_CLEAN_CACHE                 1038
#define IDC_RESTART_CACHE               1039
#define IDC_NOTIFY_PROG                 1040
#define IDC_BROWSE_CACHE                1041
#define IDC_LOOKFORSUB                  1042
#define IDD_OPT_MCACHE                  1043
#define IDC_DRIVER_LIST                 1044
#define IDC_AA_LIST                     1045
#define IDC_ZOOM_SCALABLE               1046
#define IDD_OPENFILE                    1047
#define IDC_SINGLE_INSTANCE             1048
#define IDC_VIDEO_LIST                  1049
#define IDC_FONT_LIST                   1050
#define IDC_BROWSE_FONT                 1051
#define IDC_USE_FONT                    1052
#define IDC_SAVEOPT                     1053
#define IDC_PORT                        1054
#define IDC_RTSP                        1055
#define IDC_TIMEOUT                     1056
#define IDC_BUFFER                      1057
#define IDC_REBUFFER_LEN                1058
#define IDC_REBUFFER                    1059
#define IDC_ODTREE                      1060
#define IDC_VIEWSG                      1061
#define IDC_FORCE_SIZE                  1062
#define IDC_USE_RENDER3D                1063
#define IDC_ODINFO                      1064
#define IDC_WORLD                       1065
#define IDC_GOGPAC                      1066
#define IDC_GOOSMO4                     1067
#define IDC_DUMP_XMT                    1068
#define IDC_OBJECT_TIME                 1069
#define IDC_FORMAT_YUV                  1070
#define IDC_DRAW_BOUNDS                 1071
#define IDC_REORDER                     1072
#define IDC_TEXTURE_MODE                1073
#define IDC_SWITCH_RES                  1074
#define IDC_AUDEC_LIST                  1075
#define IDC_VIDEC_LIST                  1076
#define IDC_ASSOCIATE                   1077
#define IDC_RASTER_OUTLINE              1078
#define IDC_EMUL_POW2                   1079
#define IDC_DISABLE_POLY_AA             1080
#define IDC_WIRE_NONE                   1081
#define IDC_WIRE_ONLY                   1082
#define IDC_WIRE_BOTH                   1083
#define IDC_DISABLE_TX_RECT             1084
#define IDC_BITMAP_USE_PIXEL            1085
#define IDC_TEXTURE_TEXT                1086
#define IDC_SLIDER                      1087
#define ID_SLIDER                       1088
#define IDC_SELECT                      1089
#define IDC_NO_BACKCULL                 1090
#define IDC_FILES_EXT                   1091
#define IDC_VIEWSEL                     1094
#define IDC_ADDRESS                     1096
#define IDC_DUMTXT                      1097
#define IDC_FILELIST                    1109
#define IDC_BROWSE_MCACHE               1110
#define IDC_MCACHE_OVERWRITE            1111
#define IDC_MCACHE_USENAME              1112
#define IDC_BASEPRES                    1113
#define ID_FILE_EXIT                    1114
#define ID_H_ABOUT                      1115
#define ID_PLAYLIST_LOOP                1116
#define ID_FILEOPEN                     1117
#define ID_VIEW_CONTROL                 1118
#define ID_VIEW_ORIGINAL                1119
#define ID_VIEW_FULLSCREEN              1120
#define ID_AR_KEEP                      1121
#define IDC_DRAW_NORMALS                1122
#define ID_AR_FILL                      1122
#define ID_AR_43                        1123
#define IDC_BACK_CULL                   1123
#define ID_AR_169                       1124
#define IDC_DRAW_MODE                   1124
#define ID_SHORTCUTS                    1125
#define ID_FILE_RESTART                 1126
#define ID_OPT_QUALITY                  1127
#define ID_FILE_PROP                    1128
#define ID_FILE_STEP                    1129
#define IDD_CONFIGURE                   1130
#define ID_VIEW_SCALABLE                1131
#define ID_OPEN_URL                     1132
#define ID_FILE_RELOAD                  1133
#define ID_FILE_PLAY                    1134
#define ID_NAVIGATE_NONE                1135
#define ID_NAVIGATE_WALK                1136
#define ID_NAVIGATE_FLY                 1137
#define ID_NAVIGATE_EXAM                1138
#define ID_NAVIGATE_PAN                 1139
#define ID_NAVIGATE_SLIDE               1140
#define ID_NAVIGATE_GAME                1150
#define ID_NAV_RESET                    1151
#define ID_FILE_STOP                    1152
#define ID_FILE_PREV                    1155
#define ID_FILE_NEXT                    1156
#define ID_FILE_PROPS                   1157
#define ID_SWITCH_RENDER                1158
#define ID_RELOAD_TERMINAL              1159
#define ID_VIEW_PLAYLIST                1160
#define ID_NAVIGATE_ORBIT               1161
#define ID_COLLIDE_NONE                 1162
#define ID_COLLIDE_REG                  1163
#define ID_COLLIDE_DISP                 1164
#define ID_GRAVITY                      1165
#define ID_HEADLIGHT                    1166
#define ID_NAV_INFO                     1167
#define ID_NAV_PREV                     1168
#define ID_NAV_NEXT                     1169
#define ID_CLEAR_NAV                    1170
#define ID_TIMER                        1171
#define ID_FPS                          1172
#define ID_VIEWPORT_EMPTY               1173
#define ID_PL_REM_ALL                   1174
#define ID_PL_REM_DEAD                  1175
#define ID_PL_ADD_DIR_REC               1176
#define ID_PL_ADD_FILE                  1177
#define ID_PL_REM_FILE                  1178
#define ID_PL_OPEN                      1179
#define ID_PL_SAVE                      1180
#define ID_PL_UP                        1181
#define ID_PL_DOWN                      1182
#define ID_VIEW_PL                      1183
#define ID_PL_ADD_DIR                   1184
#define ID_PL_ADD_URL                   1185
#define ID_PL_PLAY                      1186
#define ID_PL_SEL_REV                   1187
#define ID_PL_SORT_TITLE                1188
#define ID_PL_SORT_FILE                 1189
#define ID_PL_SORT_DUR                  1190
#define ID_PL_SORT_REV                  1191
#define ID_PL_RANDOM                    1192
#define ID_ADD_SUBTITLE                 1193
#define ID_NAVIGATE_VR                  1194
#define ID_REC_ENABLE                   1195
#define ID_REC_STOP                     1196
#define ID_REC_ABORT                    1197
#define ID_AUDIO_EMPTY                  1198
#define ID_VIDEO_EMPTY                  1199
#define ID_SUBS_EMPTY                   1200
#define ID_VIEW_CPU                     1201
#define IDC_SAX_PROGRESSIVE             1202
#define IDC_SAX_DELAY                   1203
#define IDC_HTTP_PROXY                  1204
#define IDC_HTTP_USE_PROXY              1205
#define ID_VP_0                         1300
#define ID_VP_1                         1301
#define ID_VP_2                         1302
#define ID_VP_3                         1303
#define ID_VP_4                         1304
#define ID_VP_5                         1305
#define ID_VP_6                         1306
#define ID_VP_7                         1307
#define ID_VP_8                         1308
#define ID_VP_9                         1309
#define ID_VP_10                        1310
#define ID_VP_11                        1311
#define ID_VP_12                        1312
#define ID_VP_13                        1313
#define ID_VP_14                        1314
#define ID_VP_15                        1315
#define ID_VP_16                        1316
#define ID_VP_17                        1317
#define ID_VP_18                        1318
#define ID_VP_19                        1319
#define ID_NAV_PREV_0                   1320
#define ID_NAV_PREV_1                   1321
#define ID_NAV_PREV_2                   1322
#define ID_NAV_PREV_3                   1323
#define ID_NAV_PREV_4                   1324
#define ID_NAV_PREV_5                   1325
#define ID_NAV_PREV_6                   1326
#define ID_NAV_PREV_7                   1327
#define ID_NAV_PREV_8                   1328
#define ID_NAV_PREV_9                   1329
#define ID_NAV_NEXT_0                   1330
#define ID_NAV_NEXT_1                   1331
#define ID_NAV_NEXT_2                   1332
#define ID_NAV_NEXT_3                   1333
#define ID_NAV_NEXT_4                   1334
#define ID_NAV_NEXT_5                   1335
#define ID_NAV_NEXT_6                   1336
#define ID_NAV_NEXT_7                   1337
#define ID_NAV_NEXT_8                   1338
#define ID_NAV_NEXT_9                   1339
#define ID_SELOBJ_0                     1340
#define ID_SELOBJ_1                     1341
#define ID_SELOBJ_2                     1342
#define ID_SELOBJ_3                     1343
#define ID_SELOBJ_4                     1344
#define ID_SELOBJ_5                     1345
#define ID_SELOBJ_6                     1346
#define ID_SELOBJ_7                     1347
#define ID_SELOBJ_8                     1348
#define ID_SELOBJ_9                     1349
#define ID_SETCHAP_FIRST                2000
#define ID_SETCHAP_LAST                 2200

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        189
#define _APS_NEXT_COMMAND_VALUE         32961
#define _APS_NEXT_CONTROL_VALUE         1129
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
